@@ -23,10 +23,9 @@ test_that("Interrogating with an agent yields the correct results", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_schema_match()` function with a `col_schema` object
   # to create a validation step, then, `interrogate()`
   schema <- 
@@ -53,10 +52,9 @@ test_that("Interrogating with an agent yields the correct results", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Expect an error if a `col_schema` object isn't provided to `schema`
   expect_error(
     create_agent(tbl = small_table) %>%
@@ -88,10 +86,9 @@ test_that("Interrogating with an agent yields the correct results", {
   expect_equivalent(validation$validation_set$n_failed, 1)
   expect_equivalent(validation$validation_set$f_passed, 0)
   expect_equivalent(validation$validation_set$f_failed, 1)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_is_character()` function to create
   # a validation step, then, `interrogate()`
   validation <-
@@ -110,10 +107,9 @@ test_that("Interrogating with an agent yields the correct results", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_is_numeric()` function to create
   # a validation step, then, `interrogate()`
   validation <-
@@ -132,10 +128,9 @@ test_that("Interrogating with an agent yields the correct results", {
   expect_equivalent(validation$validation_set$n_failed, 1)
   expect_equivalent(validation$validation_set$f_passed, 0)
   expect_equivalent(validation$validation_set$f_failed, 1)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_is_posix()` function to create
   # a validation step, then, `interrogate()`
   validation <-
@@ -154,10 +149,9 @@ test_that("Interrogating with an agent yields the correct results", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_is_date()` function to create
   # a validation step, then, `interrogate()`
   validation <-
@@ -176,10 +170,9 @@ test_that("Interrogating with an agent yields the correct results", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_is_integer()` function to create
   # a validation step, then, `interrogate()`
   validation <-
@@ -198,10 +191,9 @@ test_that("Interrogating with an agent yields the correct results", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_is_logical()` function to create
   # a validation step, then, `interrogate()`
   validation <-
@@ -220,8 +212,6 @@ test_that("Interrogating with an agent yields the correct results", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
 })
 
@@ -248,10 +238,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 1)
   expect_equivalent(validation$validation_set$f_passed, 0.92308)
   expect_equivalent(validation$validation_set$f_failed, 0.07692)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_vals_between()` function to create
   # a validation step (with a precondition), then,
   # `interrogate()`
@@ -275,6 +264,8 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
+  expect_equivalent(nrow(validation$validation_set), 1)
+  
   
   # Use the `col_vals_between()` function to create
   # a validation step, then, `interrogate()`; using
@@ -298,10 +289,32 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 6)
   expect_equivalent(validation$validation_set$f_passed, 0.53846)
   expect_equivalent(validation$validation_set$f_failed, 0.46154)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
+  # Use the `col_vals_gt()` function to create
+  # a validation step (comparison with a character value)
+  validation <-
+    create_agent(tbl = small_table) %>%
+    col_vals_between(
+      columns = vars(f),
+      left = "i", right = "p") %>%
+    interrogate()
+  
+  # Expect certain values in `validation$validation_set`
+  expect_equivalent(validation$tbl_name, "small_table")
+  expect_equivalent(validation$validation_set$assertion_type, "col_vals_between")
+  expect_equivalent(validation$validation_set$column, "f")
+  expect_true(is.list(validation$validation_set[["values"]]))
+  expect_false(validation$validation_set$all_passed)
+  expect_equivalent(validation$validation_set$n, 13)
+  expect_equivalent(validation$validation_set$n_passed, 7)
+  expect_equivalent(validation$validation_set$n_failed, 6)
+  expect_equivalent(validation$validation_set$f_passed, 0.53846)
+  expect_equivalent(validation$validation_set$f_failed, 0.46154)
+  expect_equivalent(nrow(validation$validation_set), 1)
+  
+  
   # Use the `col_vals_between()` function to create
   # a validation step, then, `interrogate()`; using
   # a column name for `right`
@@ -324,10 +337,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 2)
   expect_equivalent(validation$validation_set$f_passed, 0.84615)
   expect_equivalent(validation$validation_set$f_failed, 0.15385)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_vals_not_between()` function to create
   # a validation step, then, `interrogate()`
   validation <-
@@ -349,10 +361,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 4)
   expect_equivalent(validation$validation_set$f_passed, 0.69231)
   expect_equivalent(validation$validation_set$f_failed, 0.30769)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_vals_not_between()` function to create
   # a validation step (with a precondition), then,
   # `interrogate()`
@@ -376,6 +387,8 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 4)
   expect_equivalent(validation$validation_set$f_passed, 0.63636)
   expect_equivalent(validation$validation_set$f_failed, 0.36364)
+  expect_equivalent(nrow(validation$validation_set), 1)
+  
   
   # Use the `col_vals_equal()` function to create
   # a validation step, then, `interrogate()`
@@ -395,10 +408,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 12)
   expect_equivalent(validation$validation_set$f_passed, 0.07692)
   expect_equivalent(validation$validation_set$f_failed, 0.92308)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_vals_equal()` function to create
   # a validation step (with a precondition), then,
   # `interrogate()`
@@ -422,6 +434,32 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 10)
   expect_equivalent(validation$validation_set$f_passed, 0.09091)
   expect_equivalent(validation$validation_set$f_failed, 0.90909)
+  expect_equivalent(nrow(validation$validation_set), 1)
+  
+  
+  # Use the `col_vals_equal()` function to create
+  # a validation step (equality for a character value)
+  validation <-
+    create_agent(tbl = small_table) %>%
+    col_vals_equal(
+      columns = vars(f),
+      value = "high"
+    ) %>%
+    interrogate()
+  
+  # Expect certain values in `validation$validation_set`
+  expect_equivalent(validation$tbl_name, "small_table")
+  expect_equivalent(validation$validation_set$assertion_type, "col_vals_equal")
+  expect_equivalent(validation$validation_set$column, "f")
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), "high")
+  expect_false(validation$validation_set$all_passed)
+  expect_equivalent(validation$validation_set$n, 13)
+  expect_equivalent(validation$validation_set$n_passed, 6)
+  expect_equivalent(validation$validation_set$n_failed, 7)
+  expect_equivalent(validation$validation_set$f_passed, 0.46154)
+  expect_equivalent(validation$validation_set$f_failed, 0.53846)
+  expect_equivalent(nrow(validation$validation_set), 1)
+  
   
   # Use the `col_vals_not_equal()` function to create
   # a validation step, then, `interrogate()`
@@ -441,10 +479,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 1)
   expect_equivalent(validation$validation_set$f_passed, 0.92308)
   expect_equivalent(validation$validation_set$f_failed, 0.07692)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_vals_not_equal()` function to create
   # a validation step, then, `interrogate()`; using
   # a column name for `value`
@@ -464,10 +501,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_vals_not_equal()` function to create
   # a validation step (with a precondition), then,
   # `interrogate()`
@@ -491,6 +527,8 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 1)
   expect_equivalent(validation$validation_set$f_passed, 0.90909)
   expect_equivalent(validation$validation_set$f_failed, 0.09091)
+  expect_equivalent(nrow(validation$validation_set), 1)
+  
   
   # Use the `col_vals_gt()` function to create
   # a validation step, then, `interrogate()`; using
@@ -511,13 +549,12 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_vals_gt()` function to create
-  # a validation step, then, `interrogate()`; using
-  # a column name for `value`
+  # a validation step (with a precondition), then,
+  # `interrogate()`; using a column name for `value`
   expect_warning(regexp = NA,
     validation <-
       create_agent(tbl = small_table) %>%
@@ -538,10 +575,51 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
+  # Use the `col_vals_gt()` function to create
+  # a validation step (comparison with a Date value)
+  validation <-
+    create_agent(tbl = small_table) %>%
+    col_vals_gt(columns = vars(date_time), value = "2016-01-05") %>%
+    interrogate()
+  
+  # Expect certain values in `validation$validation_set`
+  expect_equivalent(validation$tbl_name, "small_table")
+  expect_equivalent(validation$validation_set$assertion_type, "col_vals_gt")
+  expect_equivalent(validation$validation_set$column, "date_time")
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), "2016-01-05")
+  expect_false(validation$validation_set$all_passed)
+  expect_equivalent(validation$validation_set$n, 13)
+  expect_equivalent(validation$validation_set$n_passed, 11)
+  expect_equivalent(validation$validation_set$n_failed, 2)
+  expect_equivalent(validation$validation_set$f_passed, 0.84615)
+  expect_equivalent(validation$validation_set$f_failed, 0.15385)
+  expect_equivalent(nrow(validation$validation_set), 1)
+  
+  
+  # Use the `col_vals_gt()` function to create
+  # a validation step (comparison with a character value)
+  validation <-
+    create_agent(tbl = small_table) %>%
+    col_vals_gt(columns = vars(f), value = "l") %>%
+    interrogate()
+  
+  # Expect certain values in `validation$validation_set`
+  expect_equivalent(validation$tbl_name, "small_table")
+  expect_equivalent(validation$validation_set$assertion_type, "col_vals_gt")
+  expect_equivalent(validation$validation_set$column, "f")
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), "l")
+  expect_false(validation$validation_set$all_passed)
+  expect_equivalent(validation$validation_set$n, 13)
+  expect_equivalent(validation$validation_set$n_passed, 7)
+  expect_equivalent(validation$validation_set$n_failed, 6)
+  expect_equivalent(validation$validation_set$f_passed, 0.53846)
+  expect_equivalent(validation$validation_set$f_failed, 0.46154)
+  expect_equivalent(nrow(validation$validation_set), 1)
+  
+  
   # Use the `rows_distinct()` function to create
   # a validation step, then, `interrogate()`
   validation <-
@@ -560,10 +638,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 2)
   expect_equivalent(validation$validation_set$f_passed, 0.84615)
   expect_equivalent(validation$validation_set$f_failed, 0.15385)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `rows_distinct()` function to create
   # a validation step (with a precondition), then,
   # `interrogate()`
@@ -585,6 +662,8 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
+  expect_equivalent(nrow(validation$validation_set), 1)
+  
   
   # Use the `rows_distinct()` function to create
   # a validation step for selected columns, then,
@@ -605,6 +684,8 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 2)
   expect_equivalent(validation$validation_set$f_passed, 0.84615)
   expect_equivalent(validation$validation_set$f_failed, 0.15385)
+  expect_equivalent(nrow(validation$validation_set), 1)
+  
   
   # Use the `col_vals_in_set()` function to create
   # a validation step, then, `interrogate()`
@@ -624,10 +705,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_vals_not_in_set()` function to create
   # a validation step, then, `interrogate()`
   validation <-
@@ -646,10 +726,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Make another pass with the `col_vals_not_in_set()`
   # function to create a validation step, then, perform an
   # interrogation that fails every row
@@ -669,10 +748,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_vals_not_null()` function to create
   # a validation step, then, `interrogate()`
   validation <-
@@ -691,10 +769,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 2)
   expect_equivalent(validation$validation_set$f_passed, 0.84615)
   expect_equivalent(validation$validation_set$f_failed, 0.15385)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_vals_not_null()` function to create
   # a validation step (with a precondition), then,
   # `interrogate()`
@@ -718,6 +795,8 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
+  expect_equivalent(nrow(validation$validation_set), 1)
+  
   
   # Use the `col_vals_null()` function to create
   # a validation step, then, `interrogate()`
@@ -737,10 +816,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 11)
   expect_equivalent(validation$validation_set$f_passed, 0.15385)
   expect_equivalent(validation$validation_set$f_failed, 0.84615)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_vals_null()` function to create
   # a validation step (with a precondition), then,
   # `interrogate()`
@@ -764,6 +842,8 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
+  expect_equivalent(nrow(validation$validation_set), 1)
+  
   
   # Use the `col_vals_regex()` function to create
   # a validation step, then, `interrogate()`
@@ -786,10 +866,9 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
-  
-  # Expect a single row in `validation$validation_set`
   expect_equivalent(nrow(validation$validation_set), 1)
   
+  
   # Use the `col_vals_regex()` function to create
   # a validation step (with a precondition), then,
   # `interrogate()`
@@ -813,6 +892,7 @@ test_that("Interrogating for valid row values", {
   expect_equivalent(validation$validation_set$n_failed, 0)
   expect_equivalent(validation$validation_set$f_passed, 1)
   expect_equivalent(validation$validation_set$f_failed, 0)
+  expect_equivalent(nrow(validation$validation_set), 1)
 })
 
 test_that("Interrogating with an agent incorporates the `na_pass` option", {
